% chose a random point into an hypersphere with weighted dimensions
function x0=randomIC_radius_D(dim,R,xe,weight)

pos=zeros(1,dim); % initialize the vector position

% in order to define a generic direction, standard normalized distributed
% number are generated in each direction. This generate a vetor with a
% uniformly distributed direction (proven at
% http://corysimon.github.io/articles/uniformdistn-on-sphere/, alternative
% method 1). Each direction is streched by sqrt(weight(i)) in order to
% compensate that it is an hyperellipsoid.
for i=1:dim
    pos(i)=randn/sqrt(weight(i));
end

% once a direction is defined by normalizing the pos vector by its weighted
% length. Then a uniformly distributed random number for the radius is
% generated and multiplied by the radius. In order to avoid to have more
% points close to the center, the radius is scaled by the dimension as
% illustrated in the equation. This increase the probability of having a
% point far from the center, compensating that close to the center surfaces
% with equal radius are smaller.
x0=pos/normweight_D(pos,weight)*(rand*R^dim)^(1/dim)+xe;


% % to verify the code, you can run the following script. First it is
% verified in dimension 2, then in dimension 3 taking a section of it
% xe=[0 0];
% R=1;
% weight=[1 1/20];
% dim=2;
% vect=zeros(100000,2);
% for i=1:length(vect(:,1))
%     vect(i,:)=randomIC_radius(dim,R,xe,weight);
% end
% figure;plot(vect(:,1),vect(:,2),'.');
% 
% % or
% 
% xe=[0 0 0];
% dim=3;
% weight=[1 1/20 1/50];
% vect=zeros(10000000,3);
% for i=1:length(vect(:,1))
%     vect(i,:)=randomIC_radius(dim,R,xe,weight);
% end
% temp=find(abs(vect(:,3))<0.01);
% vect12=vect(temp,:);
% figure;plot(vect12(:,1),vect12(:,2),'.');
